@@ -13,7 +13,6 @@ class CloudAssetInventory(Base):
     def __init__(self, credentials):
         """Initialize a class instance."""
         self.asset = build('cloudasset', 'v1', credentials=credentials, cache_discovery=False)
-        # self.asset_v1p5alpha1 = build('cloudasset', 'v1p5alpha1', credentials=credentials, cache_discovery=False)
 
         self.asset_v1 = asset_v1
         self.credentials = credentials
@@ -33,6 +32,8 @@ class CloudAssetInventory(Base):
         dataset=None,
         table=None,
         force=False,
+        separate_tables_per_asset_type=False,
+        partition_spec=None,
     ):
         """Export Assets to BigQuery."""
         body = {
@@ -43,6 +44,8 @@ class CloudAssetInventory(Base):
                     'dataset': dataset,
                     'table': table,
                     'force': force,
+                    'separateTablesPerAssetType': separate_tables_per_asset_type,
+                    'partitionSpec': partition_spec,
                 },
             },
             'readTime': read_time,
