@@ -12,7 +12,7 @@ class Directory(Base):
 
     def __init__(self, credentials):
         """Initialize a class instance."""
-        self.admin = build('admin', 'directory_v1', credentials=credentials)
+        self.admin = build('admin', 'directory_v1', credentials=credentials, cache_discovery=False)
         self.customer_id = 'C00q9u7iu'
         self.credentials = credentials
 
