@@ -10,7 +10,7 @@ class GroupsSettings(Base):
 
     def __init__(self, credentials):
         """Initialize a class instance."""
-        self.groupssettings = build('groupssettings', 'v1', credentials=credentials)
+        self.groupssettings = build('groupssettings', 'v1', credentials=credentials, cache_discovery=False)
 
         self.defaults = {
             # Set up default group settings that won't change
