@@ -10,7 +10,7 @@ class Reports(Base):
 
     def __init__(self, credentials):
         """Initialize a class instance."""
-        self.admin = build('admin', 'reports_v1', credentials=credentials)
+        self.admin = build('admin', 'reports_v1', credentials=credentials, cache_discovery=False)
 
     def get_activities(self, user, app):
         """Return list of user activities."""
